import React, { useEffect, useState } from 'react';
import { StaticQuery, graphql, Link } from 'gatsby';
import styled from 'styled-components';
import { Icon } from '@deer-ui/core';
const QUERY = graphql `
  query Sidebar {
    allSitePage {
      edges {
        node {
          id
          path
          context {
            frontmatter {
              title
              menu
              order
            }
          }
        }
      }
    }

    site {
      siteMetadata {
        menu
        defaultShowAllMenu
      }
    }
  }
`;
const createOrFindGroup = (name, groups) => {
    let group = groups.find((group) => group.name === name);
    if (!group) {
        group = { name, pages: [] };
        groups.push(group);
    }
    return group;
};
const sortByOrder = (a, b) => {
    const diff = (a.context.frontmatter.order || 0) - (b.context.frontmatter.order || 0);
    return diff === 0 ? 0 : diff > 0 ? 1 : -1;
};
const pagesToNavGroups = (pages) => pages.reduce((groups, page) => {
    if (!page.context.frontmatter.menu) {
        return groups;
    }
    const group = createOrFindGroup(page.context.frontmatter.menu, groups);
    group.pages.push(page);
    group.pages.sort(sortByOrder);
    return groups;
}, []);
const ListGroup = styled.ul `
  margin: 0;
  padding: 0;

  ul {
    /* padding: 0 0 0 10px; */
  }
`;
const docMenuWidth = `200px`;
const Nav = styled.nav `
  /* padding: 0 20px; */
  background-color: #fafafa;
  position: fixed;
  left: 0;
  top: 50px;
  bottom: 0;
  width: ${docMenuWidth};
  overflow-y: auto;
`;
const NavGroup = styled(ListGroup) `
  /* margin-bottom: 20px; */
`;
const NavItemBasic = styled.div `
  padding: 12px 20px;
`;
const NavGroupTitle = styled(NavItemBasic) `
  cursor: pointer;

  .title {
    font-size: 16px;
    font-weight: 500;
  }
`;
const NavGroupMenu = styled(ListGroup) `
  height: auto;
  transition: padding 0.2s ease;
  padding: 5px 0;
  &._hide {
    height: 0;
    opacity: 0;
    padding: 0;
    visibility: hidden;
  }
`;
const NavGroupMenuItem = styled.li `
  list-style-type: none;

  a {
    padding: 8px 10px 8px 30px;
    color: ${({ theme }) => theme.color['nav-link']};
    display: block;
    transition: base;
    transition-property: color;
    border-left: 3px;
    border-color: transparent;

    &:hover {
      color: ${({ theme }) => theme.color['nav-link-hover']};
      background-color: ${({ theme }) => theme.color['nav-link-hover-bg']};
    }

    &.active {
      font-weight: 600;
      border-left: 3px solid ${({ theme }) => theme.color.primary};
      background-color: ${({ theme }) => theme.color['nav-link-hover-bg']};
    }
  }
`;
const sortGroupsWithConfig = (sideMenuFromConfig) => (a, b) => {
    const indexA = sideMenuFromConfig.indexOf(a.name);
    const indexB = sideMenuFromConfig.indexOf(b.name);
    const diff = indexA - indexB;
    // eslint-disable-next-line no-nested-ternary
    return diff === 0 ? 0 : (diff < 0 ? -1 : 1);
};
const NavGroupWrapper = ({ navGroup, defaultShowAllMenu = true }) => {
    const [isShow, setIsShow] = useState(defaultShowAllMenu);
    return (React.createElement(NavGroup, { key: navGroup.name },
        React.createElement(NavGroupTitle, { className: "layout a-i-c j-c-b", onClick: (e) => {
                setIsShow(!isShow);
            } },
            React.createElement("span", { className: "title" }, navGroup.name),
            React.createElement(Icon, { n: isShow ? 'chevron-down' : 'chevron-right' })),
        React.createElement(NavGroupMenu, { className: isShow ? 'show' : '_hide' }, navGroup.pages.map((page) => (React.createElement(NavGroupMenuItem, { key: page.id },
            React.createElement(Link, { activeClassName: "active", to: page.path, ref: (e) => {
                    if (!isShow && e) {
                        const isActive = e.classList.contains('active');
                        if (isActive) {
                            setIsShow(true);
                        }
                    }
                } }, page.context.frontmatter.title)))))));
};
export function SideNav() {
    useEffect(() => {
        const sideNav = document.querySelector('#sideNav');
        if (!sideNav)
            return;
        const activeSideNavItem = sideNav.querySelector('.active');
        if (activeSideNavItem) {
            sideNav.scrollTop = activeSideNavItem.offsetTop;
        }
    }, []);
    return (React.createElement(StaticQuery, { query: QUERY, render: (data) => {
            const navGroups = pagesToNavGroups(data.allSitePage.edges
                .map((edge) => edge.node)
                .filter((node) => node.context && node.context.frontmatter));
            navGroups.sort(sortGroupsWithConfig(data.site.siteMetadata.menu));
            return (React.createElement(Nav, { id: "sideNav" }, navGroups.map((navGroup) => (React.createElement(NavGroupWrapper, { key: navGroup.name, defaultShowAllMenu: data.site.siteMetadata.defaultShowAllMenu, navGroup: navGroup })))));
        } }));
}
